@@ -105,9 +105,6 @@ class Matcher : public PatternMatcher<reflex::Pattern> {
       tab_(matcher.tab_)
   {
     DBGLOG("Matcher::Matcher(matcher)");
-    bmd_ = matcher.bmd_;
-    if (bmd_ != 0)
-      std::memcpy(bms_, matcher.bms_, sizeof(bms_));
   }
   /// Assign a matcher.
   Matcher& operator=(const Matcher& matcher) ///< matcher to copy
@@ -115,9 +112,6 @@ class Matcher : public PatternMatcher<reflex::Pattern> {
     PatternMatcher<reflex::Pattern>::operator=(matcher);
     ded_ = matcher.ded_;
     tab_ = matcher.tab_;
-    bmd_ = matcher.bmd_;
-    if (bmd_ != 0)
-      std::memcpy(bms_, matcher.bms_, sizeof(bms_));
     return *this;
   }
   /// Polymorphic cloning.
@@ -132,7 +126,6 @@ class Matcher : public PatternMatcher<reflex::Pattern> {
     PatternMatcher<reflex::Pattern>::reset(opt);
     ded_ = 0;
     tab_.resize(0);
-    bmd_ = 0;
   }
   /// Returns captured text as a std::pair<const char*,size_t> with string pointer (non-0-terminated) and length.
   virtual std::pair<const char*,size_t> operator[](size_t n) const
@@ -446,10 +439,6 @@ class Matcher : public PatternMatcher<reflex::Pattern> {
   std::vector<int>  lap_;      ///< lookahead position in input that heads a lookahead match (indexed by lookahead number)
   std::stack<Stops> stk_;      ///< stack to push/pop stops
   FSM               fsm_;      ///< local state for FSM code
-  uint16_t          lcp_;      ///< primary least common character position in the pattern prefix or 0xffff for pure Boyer-Moore
-  uint16_t          lcs_;      ///< secondary least common character position in the pattern prefix or 0xffff for pure Boyer-Moore
-  size_t            bmd_;      ///< Boyer-Moore jump distance on mismatch, B-M is enabled when bmd_ > 0
-  uint8_t           bms_[256]; ///< Boyer-Moore skip array
   bool              mrk_;      ///< indent \i or dedent \j in pattern found: should check and update indent stops
   bool              anc_;      ///< match is anchored, advance slowly to retry when searching
 };
