@@ -74,16 +74,19 @@ extern bool flag_any_line;
 extern bool flag_basic_regexp;
 extern bool flag_best_match;
 extern bool flag_bool;
+extern bool flag_color_term;
 extern bool flag_confirm;
 extern bool flag_count;
 extern bool flag_cpp;
 extern bool flag_csv;
 extern bool flag_decompress;
 extern bool flag_dereference;
+extern bool flag_dereference_files;
 extern bool flag_files;
 extern bool flag_files_with_matches;
 extern bool flag_files_without_match;
 extern bool flag_fixed_strings;
+extern bool flag_glob_ignore_case;
 extern bool flag_hex;
 extern bool flag_hex_star;
 extern bool flag_hex_cbr;
@@ -108,6 +111,7 @@ extern bool flag_pretty;
 extern bool flag_quiet;
 extern bool flag_sort_rev;
 extern bool flag_stdin;
+extern bool flag_tty_term;
 extern bool flag_usage_warnings;
 extern bool flag_word_regexp;
 extern bool flag_xml;
@@ -135,10 +139,14 @@ extern Action flag_devices_action;
 extern Action flag_directories_action;
 extern size_t flag_after_context;
 extern size_t flag_before_context;
+extern size_t flag_exclude_iglob_size;
+extern size_t flag_exclude_iglob_dir_size;
 extern size_t flag_fuzzy;
 extern size_t flag_hex_after;
 extern size_t flag_hex_before;
 extern size_t flag_hex_columns;
+extern size_t flag_include_iglob_size;
+extern size_t flag_include_iglob_dir_size;
 extern size_t flag_jobs;
 extern size_t flag_max_count;
 extern size_t flag_max_depth;
@@ -171,6 +179,7 @@ extern const char *flag_format_open;
 extern const char *flag_group_separator;
 extern const char *flag_hexdump;
 extern const char *flag_hyperlink;
+extern const char *flag_index;
 extern const char *flag_label;
 extern const char *flag_pager;
 extern const char *flag_replace;
@@ -195,6 +204,7 @@ extern std::vector<std::string> flag_file_extension;
 extern std::vector<std::string> flag_file_magic;
 extern std::vector<std::string> flag_filter_magic_label;
 extern std::vector<std::string> flag_glob;
+extern std::vector<std::string> flag_iglob;
 extern std::vector<std::string> flag_ignore_files;
 extern std::vector<std::string> flag_include;
 extern std::vector<std::string> flag_include_dir;
